N-fold Position Scales
scale_x_nfold.Rdscale_x_nfold() and scale_y_nfold() are variants of scale_x_continuous()
that set the trans argument to transform proportional change to n-fold
change.
scale_x_nfold.Rdscale_x_nfold() and scale_y_nfold() are variants of scale_x_continuous()
that set the trans argument to transform proportional change to n-fold
change.